@@ -23,6 +23,8 @@ enum TokenId : uint8_t {
     TokenIdBitOrEq,
     TokenIdBitShiftLeft,
     TokenIdBitShiftLeftEq,
+    TokenIdBitShiftLeftPipe,
+    TokenIdBitShiftLeftPipeEq,
     TokenIdBitShiftRight,
     TokenIdBitShiftRightEq,
     TokenIdBitXorEq,
@@ -108,12 +110,16 @@ enum TokenId : uint8_t {
     TokenIdMinusEq,
     TokenIdMinusPercent,
     TokenIdMinusPercentEq,
+    TokenIdMinusPipe,
+    TokenIdMinusPipeEq,
     TokenIdModEq,
     TokenIdPercent,
     TokenIdPlus,
     TokenIdPlusEq,
     TokenIdPlusPercent,
     TokenIdPlusPercentEq,
+    TokenIdPlusPipe,
+    TokenIdPlusPipeEq,
     TokenIdPlusPlus,
     TokenIdRBrace,
     TokenIdRBracket,
@@ -129,6 +135,8 @@ enum TokenId : uint8_t {
     TokenIdTimesEq,
     TokenIdTimesPercent,
     TokenIdTimesPercentEq,
+    TokenIdTimesPipe,
+    TokenIdTimesPipeEq,
 
     TokenIdCount,
 };
